@@ -26,10 +26,10 @@ class SwitchbotModel(StrEnum):
 
 
 class LockStatus(Enum):
-    LOCKED = 0b0000000
-    UNLOCKED = 0b0010000
-    LOCKING = 0b0100000
-    UNLOCKING = 0b0110000
-    LOCKING_STOP = 0b1000000
-    UNLOCKING_STOP = 0b1010000
-    NOT_FULLY_LOCKED = 0b1100000  # Only EU lock type
+    LOCKED = 0
+    UNLOCKED = 1
+    LOCKING = 2
+    UNLOCKING = 3
+    LOCKING_STOP = 4  # LOCKING_BLOCKED
+    UNLOCKING_STOP = 5  # UNLOCKING_BLOCKED
+    NOT_FULLY_LOCKED = 6  # LATCH_LOCKED - Only EU lock type
