@@ -5,11 +5,11 @@ import asyncio
 import logging
 from typing import Any
 
+from bleak.backends.device import BLEDevice
 from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
 
 from ..const import LockStatus
-from ..models import SwitchBotAdvertisement
-from .device import SwitchbotDevice
+from .device import SwitchbotDevice, SwitchbotOperationError
 
 COMMAND_HEADER = "57"
 COMMAND_GET_CK_IV = f"{COMMAND_HEADER}0f2103"
@@ -31,7 +31,7 @@ class SwitchbotLock(SwitchbotDevice):
 
     def __init__(
         self,
-        advertisement: SwitchBotAdvertisement,
+        device: BLEDevice,
         key_id: str,
         encryption_key: str,
         interface: int = 0,
@@ -50,8 +50,24 @@ class SwitchbotLock(SwitchbotDevice):
         self._key_id = key_id
         self._encryption_key = bytearray.fromhex(encryption_key)
         self._notifications_enabled: bool = False
-        super().__init__(advertisement.device, None, interface, **kwargs)
-        self.update_from_advertisement(advertisement)
+        super().__init__(device, None, interface, **kwargs)
+
+    @staticmethod
+    async def verify_encryption_key(
+        device: BLEDevice, key_id: str, encryption_key: str
+    ) -> bool:
+        try:
+            lock = SwitchbotLock(
+                device=device, key_id=key_id, encryption_key=encryption_key
+            )
+        except ValueError:
+            return False
+        try:
+            lock_info = await lock.get_basic_info()
+        except SwitchbotOperationError:
+            return False
+
+        return lock_info is not None
 
     async def lock(self) -> bool:
         """Send lock command."""
@@ -165,6 +181,7 @@ class SwitchbotLock(SwitchbotDevice):
             asyncio.create_task(self._disable_notifications())
 
         self._update_parsed_data(lock_data)
+        self._fire_callbacks()
 
     @staticmethod
     def _parse_lock_data(data: bytes) -> dict[str, Any]:
